@@ -50,7 +50,11 @@ from osgeo_utils.auxiliary.color_table import ColorTableLike, get_color_table
 from osgeo_utils.auxiliary.extent_util import GT, Extent
 from osgeo_utils.auxiliary.gdal_argparse import GDALArgumentParser, GDALScript
 from osgeo_utils.auxiliary.rectangle import GeoRectangle
-from osgeo_utils.auxiliary.util import GetOutputDriverFor, open_ds
+from osgeo_utils.auxiliary.util import (
+    GetOutputDriverFor,
+    enable_gdal_exceptions,
+    open_ds,
+)
 
 GDALDataType = int
 
@@ -104,6 +108,7 @@ sum all files with hidden noDataValue
 """
 
 
+@enable_gdal_exceptions
 def Calc(
     calc: MaybeSequence[str],
     outfile: Optional[PathLikeOrStr] = None,
